@@ -86,16 +86,29 @@ class __abr2keyDict(dict):
             prpKeys += pcls['key']
         prop2key = dict(zip(prpNames, prpKeys))
         #JOAO
+        print("pogo pogo")
         print ("prpNames = ", prpNames)
         print("prpKeys = ", prpKeys)
         print("prop2key: ", prop2key)
         #JOAO
         for prpName, prpKey in prop2key.items():
             self.__dict__[prop2abr[prpName]] = prpKey
+            #JOAO
+            print("the man")    
+            #JOAO
 
     def __pkcache(func):
+        #JOAO
+        print("yooo1")    
+        #JOAO
         def func_wrapper(self, *args):
+            #JOAO
+            print("yooo2")    
+            #JOAO
             if len(self.__dict__) is 0:
+                #JOAO
+                print("yooo3")    
+                #JOAO
                 self.__polulate()
             return func(self, *args)
         # this we do for sphinx.autodoc!
@@ -128,6 +141,10 @@ class __abr2keyDict(dict):
 
 
 abr2key = __abr2keyDict()
+#JOAO
+if abr2key:
+    print("abr2key:",abr2key)    
+#JOAO
 
 # physical properties 'abbr.->[hash, long]'
 properties = {
